#!/bin/bash

# Creates a QMI and then uses "dw trans" to flip a qubit
# (i.e., apply a gauge transform) in the QMI.  The solution
# is transformed by unflipping the relevant qubit.

# Exit if not being run via Bash shell:
if [ ! -n "$BASH" ] ; then 
    echo Please run this script $0 with bash; exit 1; 
fi

# Get a connection to the local simulator:
dw set connection laptop

# Get a 128-qubit sampling solver from the simulator:
dw set solver c4-sw_sample

# Make new workspace directory (examples) if it does not exist:
dw mkdir -p examples

# Change to new workspace directory:
dw cd examples

# Initialize the workspace:
dw init

# Create the QMI which represents a three-qubit chain:
dw set chain.qmi <<EOF
    Q0000 <==   5
    Q0001 <==   5
    Q0004 <==  10
    C0000 <== -10
    C0004 <== -10
EOF

# Create the gauge transform to flip Q0004:
cat > gauge.t <<EOF
    Q0000 <==  Q0000
    Q0001 <==  Q0001
    Q0004 <== ~Q0004
EOF

# Transform the QMI to the gauge transformed version:
dw trans gauge.t gauge-chain.qmi chain.qmi

# Execute the QMI:
dw exec num_reads=1000 gauge-chain.qmi

# Undo the gauge transformations on the solutions:
dw trans gauge.t chain.sol gauge-chain.sol

# Display the solution:
dw get chain.sol
