#!/bin/bash

# Use the dw constraint compiler with macros in the assertions.
# This problem is defined over five variables with four constraints.
# Generate a QUBO from the constraints, embed it and solve.

# Exit if not being run via Bash shell:
if [ ! -n "$BASH" ] ; then 
    echo Please run this script $0 with bash; exit 1; 
fi

# Get a connection to the local simulator:
dw set connection laptop

# Get a 128-qubit sampling solver from the simulator:
dw set solver c4-sw_sample

# Make new workspace directory (examples) if it does not exist:
dw mkdir -p examples

# Change to new workspace directory:
dw cd examples

# Initialize workspace:
dw init

# Define variables:
dw set variable w
dw set variable x
dw set variable y
dw set variable z
dw set variable o

# Define assertions:
dw set assert 'R1_on(w)'
dw set assert 'R2_eq(w,x)'
dw set assert 'R2_ge(x,y)'
dw set assert 'F2_1_and(y,z,o)'

# Compile the constraints to create the QUBO:
dw compile > G.q

# Embed the QUBO:
dw embed G.q

# Set the chain strength parameter via bind:
dw bind param_chain=5

# Execute the QMI:
dw exec num_reads=1000 default.qmi

# Display the sample statistics:
dw val -v default.sol

# Display the first four solutions:
for ((s=1; s<=4; ++s))
do
    dw val -v -s $s default.sol
done
